/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#include "dns/hostaddress.h"

#include <boost/version.hpp>
#include <boost/serialization/serialization.hpp>

#include "boost_assert_handler.h"

using namespace std;
using boost::asio::ip::address;

//-----------------------------------------------------------------------------
// HostAddress
//-----------------------------------------------------------------------------

HostAddress::HostAddress() :
    Ip(),
    Ttl( 0 )
{
}

HostAddress::HostAddress(
        const address &ip,
        uint32_t ttl
) :
    Ip( ip ),
    Ttl( ttl )
{
}

HostAddress::~HostAddress()
{
}

address HostAddress::get_ip() const
{
    return Ip;
}

void HostAddress::set_ip( const address &ip )
{
#if BOOST_VERSION >= 104700
    BOOST_ASSERT( ip.is_unspecified() );
#endif

    Ip = ip;
}

TimeToLive HostAddress::get_ttl() const
{
    return Ttl;
}

void HostAddress::set_ttl( const TimeToLive &ttl )
{
    Ttl = ttl;
}

template<class Archive>
void HostAddress::serialize(Archive & ar, const unsigned int version)
{
    ar & Ip;
    ar & Ttl;
}
